@@ -19,3 +19,18 @@ class Party(metaclass=PoolMeta):
                 if country and zip_ and country.code == 'ES':
                     self.es_province_code = zip_[:2]
                     break
+
+
+class Identifier(metaclass=PoolMeta):
+    __name__ = 'party.identifier'
+
+    def es_country(self):
+        if self.type == 'eu_vat':
+            return self.code[:2]
+        if self.type in {'es_cif', 'es_dni', 'es_nie', 'es_nif'}:
+            return 'ES'
+
+    def es_code(self):
+        if self.type == 'eu_vat':
+            return self.code[2:]
+        return self.code
